Class: Google::Apis::IamcredentialsV1::SignBlobResponse
- Inherits:
-
Object
- Object
- Google::Apis::IamcredentialsV1::SignBlobResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/iamcredentials_v1/classes.rb,
lib/google/apis/iamcredentials_v1/representations.rb,
lib/google/apis/iamcredentials_v1/representations.rb
Instance Attribute Summary collapse
-
#key_id ⇒ String
The ID of the key used to sign the blob.
-
#signed_blob ⇒ String
The signature for the blob.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SignBlobResponse
constructor
A new instance of SignBlobResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SignBlobResponse
Returns a new instance of SignBlobResponse.
260 261 262 |
# File 'lib/google/apis/iamcredentials_v1/classes.rb', line 260 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key_id ⇒ String
The ID of the key used to sign the blob. The key used for signing will remain
valid for at least 12 hours after the blob is signed. To verify the signature,
you can retrieve the public key in several formats from the following
endpoints: - RSA public key wrapped in an X.509 v3 certificate: https://www.
googleapis.com/service_accounts/v1/metadata/x509/ACCOUNT_EMAIL- Raw key in
JSON format: `https://www.googleapis.com/service_accounts/v1/metadata/raw/`
ACCOUNT_EMAIL - JSON Web Key (JWK): https://www.googleapis.com/
service_accounts/v1/metadata/jwk/ACCOUNT_EMAIL`
Corresponds to the JSON propertykeyId`
249 250 251 |
# File 'lib/google/apis/iamcredentials_v1/classes.rb', line 249 def key_id @key_id end |
#signed_blob ⇒ String
The signature for the blob. Does not include the original blob. After the key
pair referenced by the key_id response field expires, Google no longer
exposes the public key that can be used to verify the blob. As a result, the
receiver can no longer verify the signature.
Corresponds to the JSON property signedBlob
NOTE: Values are automatically base64 encoded/decoded in the client library.
258 259 260 |
# File 'lib/google/apis/iamcredentials_v1/classes.rb', line 258 def signed_blob @signed_blob end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
265 266 267 268 |
# File 'lib/google/apis/iamcredentials_v1/classes.rb', line 265 def update!(**args) @key_id = args[:key_id] if args.key?(:key_id) @signed_blob = args[:signed_blob] if args.key?(:signed_blob) end |