Class: Google::Apis::IamcredentialsV1::WorkforcePoolAllowedLocations

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/iamcredentials_v1/classes.rb,
lib/google/apis/iamcredentials_v1/representations.rb,
lib/google/apis/iamcredentials_v1/representations.rb

Overview

Represents a list of allowed locations for given workforce pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkforcePoolAllowedLocations

Returns a new instance of WorkforcePoolAllowedLocations.



359
360
361
# File 'lib/google/apis/iamcredentials_v1/classes.rb', line 359

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encoded_locationsString

Output only. The hex encoded bitmap of the trust boundary locations Corresponds to the JSON property encodedLocations

Returns:

  • (String)


351
352
353
# File 'lib/google/apis/iamcredentials_v1/classes.rb', line 351

def encoded_locations
  @encoded_locations
end

#locationsArray<String>

Output only. The human readable trust boundary locations. For example, ["us- central1", "europe-west1"] Corresponds to the JSON property locations

Returns:

  • (Array<String>)


357
358
359
# File 'lib/google/apis/iamcredentials_v1/classes.rb', line 357

def locations
  @locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



364
365
366
367
# File 'lib/google/apis/iamcredentials_v1/classes.rb', line 364

def update!(**args)
  @encoded_locations = args[:encoded_locations] if args.key?(:encoded_locations)
  @locations = args[:locations] if args.key?(:locations)
end